"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Desktop(google.protobuf.message.Message):
    """A desktop resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Desktop._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Desktop._Status.ValueType  # 0
        CREATING: Desktop._Status.ValueType  # 1
        """Desktop is being created."""
        ACTIVE: Desktop._Status.ValueType  # 2
        """Desktop is ready to be used."""
        DELETING: Desktop._Status.ValueType  # 3
        """Desktop is being deleted."""
        RESTARTING: Desktop._Status.ValueType  # 4
        """Desktop is restarting."""
        UPDATING: Desktop._Status.ValueType  # 5
        """Desktop is updating."""
        STARTING: Desktop._Status.ValueType  # 6
        """Desktop is starting."""
        STOPPING: Desktop._Status.ValueType  # 7
        """Desktop is stopping."""
        STOPPED: Desktop._Status.ValueType  # 8
        """Desktop is stopped."""
        ERROR: Desktop._Status.ValueType  # 9
        """Desktop did not manage start or restart."""
        CREATION_FAILED: Desktop._Status.ValueType  # 10
        """Desktop did not manage to get created or updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Desktop.Status.ValueType  # 0
    CREATING: Desktop.Status.ValueType  # 1
    """Desktop is being created."""
    ACTIVE: Desktop.Status.ValueType  # 2
    """Desktop is ready to be used."""
    DELETING: Desktop.Status.ValueType  # 3
    """Desktop is being deleted."""
    RESTARTING: Desktop.Status.ValueType  # 4
    """Desktop is restarting."""
    UPDATING: Desktop.Status.ValueType  # 5
    """Desktop is updating."""
    STARTING: Desktop.Status.ValueType  # 6
    """Desktop is starting."""
    STOPPING: Desktop.Status.ValueType  # 7
    """Desktop is stopping."""
    STOPPED: Desktop.Status.ValueType  # 8
    """Desktop is stopped."""
    ERROR: Desktop.Status.ValueType  # 9
    """Desktop did not manage start or restart."""
    CREATION_FAILED: Desktop.Status.ValueType  # 10
    """Desktop did not manage to get created or updated."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    DESKTOP_GROUP_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Desktop ID."""
    folder_id: builtins.str
    """ID of the folder that the desktop belongs to."""
    desktop_group_id: builtins.str
    """ID of the desktop group that the desktop belongs to."""
    status: global___Desktop.Status.ValueType
    """Status of the desktop."""
    name: builtins.str
    """Name of the desktop."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def resources(self) -> global___Resources:
        """Resources of the desktop."""

    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterface]: ...
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___User]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the desktop."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        desktop_group_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___Desktop.Status.ValueType = ...,
        name: builtins.str = ...,
        resources: global___Resources | None = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterface] | None = ...,
        users: collections.abc.Iterable[global___User] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "desktop_group_id", b"desktop_group_id", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "network_interfaces", b"network_interfaces", "resources", b"resources", "status", b"status", "users", b"users"]) -> None: ...

global___Desktop = Desktop

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    memory: builtins.int
    cores: builtins.int
    core_fraction: builtins.int
    def __init__(
        self,
        *,
        memory: builtins.int = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "memory", b"memory"]) -> None: ...

global___Resources = Resources

@typing.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    SUBJECT_TYPE_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    """Identity of the access binding."""
    subject_type: builtins.str
    """Type of the access binding, e.g. userAccount, serviceAccount, system."""
    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
        subject_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_id", b"subject_id", "subject_type", b"subject_type"]) -> None: ...

global___User = User

@typing.final
class NetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "subnet_id", b"subnet_id"]) -> None: ...

global___NetworkInterface = NetworkInterface



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.extension_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSION_NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    extension_name: builtins.str
    folder_id: builtins.str
    def __init__(
        self,
        *,
        extension_name: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extension_name", b"extension_name", "folder_id", b"folder_id"]) -> None: ...

global___GetExtensionRequest = GetExtensionRequest

@typing.final
class ListExtensionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    folder_id: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExtensionsRequest = ListExtensionsRequest

@typing.final
class ListExtensionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.extension_pb2.Extension]: ...
    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.extension_pb2.Extension] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extensions", b"extensions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListExtensionsResponse = ListExtensionsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MaintenanceOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    LATEST_MAINTENANCE_TIME_FIELD_NUMBER: builtins.int
    NEXT_MAINTENANCE_WINDOW_TIME_FIELD_NUMBER: builtins.int
    info: builtins.str
    """The description of the operation."""
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Delay time for the maintenance operation."""

    @property
    def latest_maintenance_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the last maintenance window."""

    @property
    def next_maintenance_window_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the next maintenance window."""

    def __init__(
        self,
        *,
        info: builtins.str = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        latest_maintenance_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        next_maintenance_window_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until", "latest_maintenance_time", b"latest_maintenance_time", "next_maintenance_window_time", b"next_maintenance_window_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["delayed_until", b"delayed_until", "info", b"info", "latest_maintenance_time", b"latest_maintenance_time", "next_maintenance_window_time", b"next_maintenance_window_time"]) -> None: ...

global___MaintenanceOperation = MaintenanceOperation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/opensearch/v1/config/opensearch.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/opensearch/v1/config/opensearch.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/opensearch/v1/config/opensearch.proto\x12%yandex.cloud.mdb.opensearch.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x90\x01\n\x11OpenSearchConfig2\x12\x35\n\x10max_clause_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1c\n\x14\x66ielddata_cache_size\x18\x04 \x01(\t\x12 \n\x18reindex_remote_whitelist\x18\x06 \x01(\tJ\x04\x08\x05\x10\x06\"\x91\x02\n\x14OpenSearchConfigSet2\x12X\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.opensearch.v1.config.OpenSearchConfig2B\x04\xe8\xc7\x31\x01\x12M\n\x0buser_config\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.opensearch.v1.config.OpenSearchConfig2\x12P\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.opensearch.v1.config.OpenSearchConfig2Bz\n\"yandex.cloud.api.mdb.opensearch.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1/config;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1/config;opensearch'
  _globals['_OPENSEARCHCONFIGSET2'].fields_by_name['effective_config']._loaded_options = None
  _globals['_OPENSEARCHCONFIGSET2'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_OPENSEARCHCONFIG2']._serialized_start=161
  _globals['_OPENSEARCHCONFIG2']._serialized_end=305
  _globals['_OPENSEARCHCONFIGSET2']._serialized_start=308
  _globals['_OPENSEARCHCONFIGSET2']._serialized_end=581
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BatchInferenceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    TASK_STATUS_FIELD_NUMBER: builtins.int
    COMPLETED_BATCHES_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    task_status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType
    completed_batches: builtins.int
    total_batches: builtins.int
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        task_status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType = ...,
        completed_batches: builtins.int = ...,
        total_batches: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["completed_batches", b"completed_batches", "task_id", b"task_id", "task_status", b"task_status", "total_batches", b"total_batches"]) -> None: ...

global___BatchInferenceMetadata = BatchInferenceMetadata

@typing.final
class BatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask: ...
    def __init__(
        self,
        *,
        task: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___BatchInferenceResponse = BatchInferenceResponse

@typing.final
class DescribeBatchInferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """Required task id"""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___DescribeBatchInferenceRequest = DescribeBatchInferenceRequest

@typing.final
class DescribeBatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask: ...
    def __init__(
        self,
        *,
        task: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___DescribeBatchInferenceResponse = DescribeBatchInferenceResponse

@typing.final
class ListBatchInferencesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID for which the list of tasks will be provided."""
    page_size: builtins.int
    page_token: builtins.str
    status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType
    """Batch inference status for filtering"""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "status", b"status"]) -> None: ...

global___ListBatchInferencesRequest = ListBatchInferencesRequest

@typing.final
class ListBatchInferencesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask]: ...
    def __init__(
        self,
        *,
        tasks: collections.abc.Iterable[yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "tasks", b"tasks"]) -> None: ...

global___ListBatchInferencesResponse = ListBatchInferencesResponse

@typing.final
class CancelBatchInferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """Task ID that should be canceled."""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___CancelBatchInferenceRequest = CancelBatchInferenceRequest

@typing.final
class CancelBatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___CancelBatchInferenceResponse = CancelBatchInferenceResponse

@typing.final
class DeleteBatchInferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """Task ID that should be deleted."""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___DeleteBatchInferenceRequest = DeleteBatchInferenceRequest

@typing.final
class DeleteBatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___DeleteBatchInferenceResponse = DeleteBatchInferenceResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.files.v1.file_pb2
import yandex.cloud.ai.files.v1.file_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class FileServiceStub:
    """FileService provides operations for managing files."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.CreateFileRequest,
        yandex.cloud.ai.files.v1.file_pb2.File,
    ]
    """Create a new file."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.GetFileRequest,
        yandex.cloud.ai.files.v1.file_pb2.File,
    ]
    """Retrieve details of a specific file by its ID."""

    GetUrl: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlRequest,
        yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlResponse,
    ]
    """Retrieve a URL for accessing or downloading a specific file."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.UpdateFileRequest,
        yandex.cloud.ai.files.v1.file_pb2.File,
    ]
    """Update an existing file."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileRequest,
        yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileResponse,
    ]
    """Delete a file by its ID."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.ListFilesRequest,
        yandex.cloud.ai.files.v1.file_service_pb2.ListFilesResponse,
    ]
    """List files in a specific folder."""

class FileServiceAsyncStub:
    """FileService provides operations for managing files."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.CreateFileRequest,
        yandex.cloud.ai.files.v1.file_pb2.File,
    ]
    """Create a new file."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.GetFileRequest,
        yandex.cloud.ai.files.v1.file_pb2.File,
    ]
    """Retrieve details of a specific file by its ID."""

    GetUrl: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlRequest,
        yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlResponse,
    ]
    """Retrieve a URL for accessing or downloading a specific file."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.UpdateFileRequest,
        yandex.cloud.ai.files.v1.file_pb2.File,
    ]
    """Update an existing file."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileRequest,
        yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileResponse,
    ]
    """Delete a file by its ID."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.files.v1.file_service_pb2.ListFilesRequest,
        yandex.cloud.ai.files.v1.file_service_pb2.ListFilesResponse,
    ]
    """List files in a specific folder."""

class FileServiceServicer(metaclass=abc.ABCMeta):
    """FileService provides operations for managing files."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.files.v1.file_service_pb2.CreateFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.files.v1.file_pb2.File, collections.abc.Awaitable[yandex.cloud.ai.files.v1.file_pb2.File]]:
        """Create a new file."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.files.v1.file_service_pb2.GetFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.files.v1.file_pb2.File, collections.abc.Awaitable[yandex.cloud.ai.files.v1.file_pb2.File]]:
        """Retrieve details of a specific file by its ID."""

    @abc.abstractmethod
    def GetUrl(
        self,
        request: yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlResponse, collections.abc.Awaitable[yandex.cloud.ai.files.v1.file_service_pb2.GetFileUrlResponse]]:
        """Retrieve a URL for accessing or downloading a specific file."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ai.files.v1.file_service_pb2.UpdateFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.files.v1.file_pb2.File, collections.abc.Awaitable[yandex.cloud.ai.files.v1.file_pb2.File]]:
        """Update an existing file."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileResponse, collections.abc.Awaitable[yandex.cloud.ai.files.v1.file_service_pb2.DeleteFileResponse]]:
        """Delete a file by its ID."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.files.v1.file_service_pb2.ListFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.files.v1.file_service_pb2.ListFilesResponse, collections.abc.Awaitable[yandex.cloud.ai.files.v1.file_service_pb2.ListFilesResponse]]:
        """List files in a specific folder."""

def add_FileServiceServicer_to_server(servicer: FileServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/config_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/config_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.loadtesting.api.v1.config import config_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/loadtesting/api/v1/config_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x33yandex/cloud/loadtesting/api/v1/config/config.proto\"k\n\x13\x43reateConfigRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=54\x12\x15\n\x0byaml_string\x18\x02 \x01(\tH\x00\x12\x0c\n\x04name\x18\n \x01(\tB\x08\n\x06\x63onfigJ\x04\x08\x03\x10\n\")\n\x14\x43reateConfigMetadata\x12\x11\n\tconfig_id\x18\x01 \x01(\t\"%\n\x10GetConfigRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\t\"j\n\x12ListConfigsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x13ListConfigsResponse\x12?\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32..yandex.cloud.loadtesting.api.v1.config.Config\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"(\n\x13\x44\x65leteConfigRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\t\")\n\x14\x44\x65leteConfigMetadata\x12\x11\n\tconfig_id\x18\x01 \x01(\t2\xbf\x05\n\rConfigService\x12\xb2\x01\n\x06\x43reate\x12\x34.yandex.cloud.loadtesting.api.v1.CreateConfigRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*%\n\x14\x43reateConfigMetadata\x12\rconfig.Config\x82\xd3\xe4\x93\x02 \"\x1b/loadtesting/api/v1/configs:\x01*\x12\x99\x01\n\x03Get\x12\x31.yandex.cloud.loadtesting.api.v1.GetConfigRequest\x1a..yandex.cloud.loadtesting.api.v1.config.Config\"/\x82\xd3\xe4\x93\x02)\x12\'/loadtesting/api/v1/configs/{config_id}\x12\x96\x01\n\x04List\x12\x33.yandex.cloud.loadtesting.api.v1.ListConfigsRequest\x1a\x34.yandex.cloud.loadtesting.api.v1.ListConfigsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/loadtesting/api/v1/configs\x12\xc3\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.loadtesting.api.v1.DeleteConfigRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*-\n\x14\x44\x65leteConfigMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/loadtesting/api/v1/configs/{config_id}Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.config_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _globals['_CREATECONFIGREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECONFIGREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=54'
  _globals['_LISTCONFIGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCONFIGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CONFIGSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CONFIGSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*%\n\024CreateConfigMetadata\022\rconfig.Config\202\323\344\223\002 \"\033/loadtesting/api/v1/configs:\001*'
  _globals['_CONFIGSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONFIGSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/loadtesting/api/v1/configs/{config_id}'
  _globals['_CONFIGSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CONFIGSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\035\022\033/loadtesting/api/v1/configs'
  _globals['_CONFIGSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CONFIGSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteConfigMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/loadtesting/api/v1/configs/{config_id}'
  _globals['_CREATECONFIGREQUEST']._serialized_start=277
  _globals['_CREATECONFIGREQUEST']._serialized_end=384
  _globals['_CREATECONFIGMETADATA']._serialized_start=386
  _globals['_CREATECONFIGMETADATA']._serialized_end=427
  _globals['_GETCONFIGREQUEST']._serialized_start=429
  _globals['_GETCONFIGREQUEST']._serialized_end=466
  _globals['_LISTCONFIGSREQUEST']._serialized_start=468
  _globals['_LISTCONFIGSREQUEST']._serialized_end=574
  _globals['_LISTCONFIGSRESPONSE']._serialized_start=576
  _globals['_LISTCONFIGSRESPONSE']._serialized_end=687
  _globals['_DELETECONFIGREQUEST']._serialized_start=689
  _globals['_DELETECONFIGREQUEST']._serialized_end=729
  _globals['_DELETECONFIGMETADATA']._serialized_start=731
  _globals['_DELETECONFIGMETADATA']._serialized_end=772
  _globals['_CONFIGSERVICE']._serialized_start=775
  _globals['_CONFIGSERVICE']._serialized_end=1478
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.mdb.greenplum.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/mdb/greenplum/v1/user_service.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a(yandex/cloud/mdb/greenplum/v1/user.proto\"x\n\x12\x43reateUserMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\tuser_name\x18\x02 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-63\"x\n\x12UpdateUserMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\tuser_name\x18\x02 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-63\"x\n\x12\x44\x65leteUserMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\tuser_name\x18\x02 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-63\"4\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"G\n\x11ListUsersResponse\x12\x32\n\x05users\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.greenplum.v1.User\"\x98\x01\n\x18GetUserAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x08revision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12@\n\tuser_name\x18\x03 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-63\"n\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x37\n\x04user\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.greenplum.v1.UserB\x04\xe8\xc7\x31\x01\"\x9f\x01\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x37\n\x04user\x18\x03 \x01(\x0b\x32#.yandex.cloud.mdb.greenplum.v1.UserB\x04\xe8\xc7\x31\x01\"w\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\tuser_name\x18\x02 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-632\x8e\x06\n\x0bUserService\x12\xa4\x01\n\x04List\x12/.yandex.cloud.mdb.greenplum.v1.ListUsersRequest\x1a\x30.yandex.cloud.mdb.greenplum.v1.ListUsersResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-greenplum/v1/clusters/{cluster_id}/users\x12\xb9\x01\n\x06\x43reate\x12\x30.yandex.cloud.mdb.greenplum.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x36\"1/managed-greenplum/v1/clusters/{cluster_id}/users:\x01*\x12\xc5\x01\n\x06Update\x12\x30.yandex.cloud.mdb.greenplum.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x42\x32=/managed-greenplum/v1/clusters/{cluster_id}/users/{user.name}:\x01*\x12\xd3\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.mdb.greenplum.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?*=/managed-greenplum/v1/clusters/{cluster_id}/users/{user_name}Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_CREATEUSERMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEUSERMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEUSERMETADATA'].fields_by_name['user_name']._loaded_options = None
  _globals['_CREATEUSERMETADATA'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_UPDATEUSERMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEUSERMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERMETADATA'].fields_by_name['user_name']._loaded_options = None
  _globals['_UPDATEUSERMETADATA'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_DELETEUSERMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEUSERMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEUSERMETADATA'].fields_by_name['user_name']._loaded_options = None
  _globals['_DELETEUSERMETADATA'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETUSERATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETUSERATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETUSERATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_GETUSERATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_GETUSERATREVISIONREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_GETUSERATREVISIONREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user']._serialized_options = b'\350\3071\001'
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0023\0221/managed-greenplum/v1/clusters/{cluster_id}/users'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\0026\"1/managed-greenplum/v1/clusters/{cluster_id}/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002B2=/managed-greenplum/v1/clusters/{cluster_id}/users/{user.name}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002?*=/managed-greenplum/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_CREATEUSERMETADATA']._serialized_start=294
  _globals['_CREATEUSERMETADATA']._serialized_end=414
  _globals['_UPDATEUSERMETADATA']._serialized_start=416
  _globals['_UPDATEUSERMETADATA']._serialized_end=536
  _globals['_DELETEUSERMETADATA']._serialized_start=538
  _globals['_DELETEUSERMETADATA']._serialized_end=658
  _globals['_LISTUSERSREQUEST']._serialized_start=660
  _globals['_LISTUSERSREQUEST']._serialized_end=712
  _globals['_LISTUSERSRESPONSE']._serialized_start=714
  _globals['_LISTUSERSRESPONSE']._serialized_end=785
  _globals['_GETUSERATREVISIONREQUEST']._serialized_start=788
  _globals['_GETUSERATREVISIONREQUEST']._serialized_end=940
  _globals['_CREATEUSERREQUEST']._serialized_start=942
  _globals['_CREATEUSERREQUEST']._serialized_end=1052
  _globals['_UPDATEUSERREQUEST']._serialized_start=1055
  _globals['_UPDATEUSERREQUEST']._serialized_end=1214
  _globals['_DELETEUSERREQUEST']._serialized_start=1216
  _globals['_DELETEUSERREQUEST']._serialized_end=1335
  _globals['_USERSERVICE']._serialized_start=1338
  _globals['_USERSERVICE']._serialized_end=2120
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/maintenance/v2/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/maintenance/v2/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/maintenance/v2/common.proto\x12\x1byandex.cloud.maintenance.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb3\x06\n\x0bMaintenance\x12\n\n\x02id\x18\x01 \x01(\t\x12H\n\rresource_path\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.maintenance.v2.Maintenance.Resource\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12@\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32/.yandex.cloud.maintenance.v2.Maintenance.Detail\x12?\n\x06status\x18\x05 \x01(\x0e\x32/.yandex.cloud.maintenance.v2.Maintenance.Status\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12start_scheduled_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17\x63ompletion_scheduled_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16max_start_scheduled_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csucceeded_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11user_controllable\x18\r \x01(\x08\x1a$\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x1a$\n\x06\x44\x65tail\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tSUCCEEDED\x10\x03\x12\r\n\tCANCELLED\x10\x04\"\xfa\x01\n\x17ListMaintenancesRequest\x12\x1c\n\x08\x63loud_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=500\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x19\n\x06\x66ilter\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100B\x0b\n\tcontainer\"s\n\x18ListMaintenancesResponse\x12>\n\x0cmaintenances\x18\x01 \x03(\x0b\x32(.yandex.cloud.maintenance.v2.Maintenance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x15GetMaintenanceRequest\x12$\n\x0emaintenance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xaa\x02\n\x1cRescheduleMaintenanceRequest\x12$\n\x0emaintenance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0freschedule_type\x18\x02 \x01(\x0e\x32>.yandex.cloud.maintenance.v2.RescheduleMaintenanceRequest.Type\x12\x30\n\x0cscheduled_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Y\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\x42n\n\x1fyandex.cloud.api.maintenance.v2ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/maintenance/v2;maintenanceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.maintenance.v2.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.maintenance.v2ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/maintenance/v2;maintenance'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['cloud_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['resource_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=500'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._loaded_options = None
  _globals['_GETMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MAINTENANCE']._serialized_start=138
  _globals['_MAINTENANCE']._serialized_end=957
  _globals['_MAINTENANCE_RESOURCE']._serialized_start=791
  _globals['_MAINTENANCE_RESOURCE']._serialized_end=827
  _globals['_MAINTENANCE_DETAIL']._serialized_start=829
  _globals['_MAINTENANCE_DETAIL']._serialized_end=865
  _globals['_MAINTENANCE_STATUS']._serialized_start=867
  _globals['_MAINTENANCE_STATUS']._serialized_end=957
  _globals['_LISTMAINTENANCESREQUEST']._serialized_start=960
  _globals['_LISTMAINTENANCESREQUEST']._serialized_end=1210
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_start=1212
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_end=1327
  _globals['_GETMAINTENANCEREQUEST']._serialized_start=1329
  _globals['_GETMAINTENANCEREQUEST']._serialized_end=1390
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=1393
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=1691
  _globals['_RESCHEDULEMAINTENANCEREQUEST_TYPE']._serialized_start=1602
  _globals['_RESCHEDULEMAINTENANCEREQUEST_TYPE']._serialized_end=1691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/disk.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/disk.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/clouddesktop/v1/disk.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1dyandex/cloud/validation.proto\"\x95\x01\n\x08\x44iskSpec\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32/.yandex.cloud.clouddesktop.v1.api.DiskSpec.TypeB\x04\xe8\xc7\x31\x01\x12\x14\n\x04size\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\".\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03HDD\x10\x01\x12\x07\n\x03SSD\x10\x02\x42w\n yandex.cloud.api.clouddesktop.v1B\x04PADDZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.disk_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1B\004PADDZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_DISKSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_DISKSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_DISKSPEC'].fields_by_name['size']._loaded_options = None
  _globals['_DISKSPEC'].fields_by_name['size']._serialized_options = b'\372\3071\002>0'
  _globals['_DISKSPEC']._serialized_start=109
  _globals['_DISKSPEC']._serialized_end=258
  _globals['_DISKSPEC_TYPE']._serialized_start=212
  _globals['_DISKSPEC_TYPE']._serialized_end=258
# @@protoc_insertion_point(module_scope)
